==> odata-client-msgraph-beta-0.1.26-sources.jar: odata/msgraph/client/beta/complex/SensitiveContentEvidence.java <==
package odata.msgraph.client.beta.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFields;

import java.util.Optional;

@JsonPropertyOrder({
    "@odata.type", 
    "match", 
    "offset", 
    "length"})
@JsonInclude(Include.NON_NULL)
public class SensitiveContentEvidence implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected ContextPath contextPath;

    @JacksonInject
    @JsonIgnore
    protected UnmappedFields unmappedFields;

    @JsonProperty("@odata.type")
    protected String odataType;

    @JsonProperty("match")
    protected String match;

    @JsonProperty("offset")
    protected Integer offset;

    @JsonProperty("length")
    protected Integer length;

    protected SensitiveContentEvidence() {
    }

    @Override
    public String odataTypeName() {
        return "microsoft.graph.sensitiveContentEvidence";
    }

    @Property(name="match")
    @JsonIgnore
    public Optional<String> getMatch() {
        return Optional.ofNullable(match);
    }

    public SensitiveContentEvidence withMatch(String match) {
        SensitiveContentEvidence _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.sensitiveContentEvidence");
        _x.match = match;
        return _x;
    }

    @Property(name="offset")
    @JsonIgnore
    public Optional<Integer> getOffset() {
        return Optional.ofNullable(offset);
    }

    public SensitiveContentEvidence withOffset(Integer offset) {
        SensitiveContentEvidence _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.sensitiveContentEvidence");
        _x.offset = offset;
        return _x;
    }

    @Property(name="length")
    @JsonIgnore
    public Optional<Integer> getLength() {
        return Optional.ofNullable(length);
    }

    public SensitiveContentEvidence withLength(Integer length) {
        SensitiveContentEvidence _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.sensitiveContentEvidence");
        _x.length = length;
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFields();
        }
        unmappedFields.put(name, value);
    }

    @Override
    @JsonIgnore
    public UnmappedFields getUnmappedFields() {
        return unmappedFields == null ? new UnmappedFields() : unmappedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builder() {
        return new Builder();
    }

    public static final class Builder {
        private String match;
        private Integer offset;
        private Integer length;
        private ChangedFields changedFields = new ChangedFields();

        Builder() {
            // prevent instantiation
        }

        public Builder match(String match) {
            this.match = match;
            this.changedFields = changedFields.add("match");
            return this;
        }

        public Builder offset(Integer offset) {
            this.offset = offset;
            this.changedFields = changedFields.add("offset");
            return this;
        }

        public Builder length(Integer length) {
            this.length = length;
            this.changedFields = changedFields.add("length");
            return this;
        }

        public SensitiveContentEvidence build() {
            SensitiveContentEvidence _x = new SensitiveContentEvidence();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFields();
            _x.odataType = "microsoft.graph.sensitiveContentEvidence";
            _x.match = match;
            _x.offset = offset;
            _x.length = length;
            return _x;
        }
    }

    private SensitiveContentEvidence _copy() {
        SensitiveContentEvidence _x = new SensitiveContentEvidence();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields;
        _x.odataType = odataType;
        _x.match = match;
        _x.offset = offset;
        _x.length = length;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("SensitiveContentEvidence[");
        b.append("match=");
        b.append(this.match);
        b.append(", ");
        b.append("offset=");
        b.append(this.offset);
        b.append(", ");
        b.append("length=");
        b.append(this.length);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}

==> odata-client-msgraph-beta-0.2.2-sources.jar: odata/msgraph/client/beta/complex/SensitiveContentEvidence.java <==
package odata.msgraph.client.beta.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Integer;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.util.Optional;

@JsonPropertyOrder({
    "@odata.type", 
    "length", 
    "match", 
    "offset"})
@JsonInclude(Include.NON_NULL)
public class SensitiveContentEvidence implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected ContextPath contextPath;

    @JacksonInject
    @JsonIgnore
    protected UnmappedFieldsImpl unmappedFields;

    @JsonProperty("@odata.type")
    protected String odataType;

    @JsonProperty("length")
    protected Integer length;

    @JsonProperty("match")
    protected String match;

    @JsonProperty("offset")
    protected Integer offset;

    protected SensitiveContentEvidence() {
    }

    @Override
    public String odataTypeName() {
        return "microsoft.graph.sensitiveContentEvidence";
    }

    @Property(name="length")
    @JsonIgnore
    public Optional<Integer> getLength() {
        return Optional.ofNullable(length);
    }

    public SensitiveContentEvidence withLength(Integer length) {
        SensitiveContentEvidence _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.sensitiveContentEvidence");
        _x.length = length;
        return _x;
    }

    @Property(name="match")
    @JsonIgnore
    public Optional<String> getMatch() {
        return Optional.ofNullable(match);
    }

    public SensitiveContentEvidence withMatch(String match) {
        SensitiveContentEvidence _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.sensitiveContentEvidence");
        _x.match = match;
        return _x;
    }

    @Property(name="offset")
    @JsonIgnore
    public Optional<Integer> getOffset() {
        return Optional.ofNullable(offset);
    }

    public SensitiveContentEvidence withOffset(Integer offset) {
        SensitiveContentEvidence _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.sensitiveContentEvidence");
        _x.offset = offset;
        return _x;
    }

    public SensitiveContentEvidence withUnmappedField(String name, Object value) {
        SensitiveContentEvidence _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builder() {
        return new Builder();
    }

    public static final class Builder {
        private Integer length;
        private String match;
        private Integer offset;
        private ChangedFields changedFields = ChangedFields.EMPTY;

        Builder() {
            // prevent instantiation
        }

        public Builder length(Integer length) {
            this.length = length;
            this.changedFields = changedFields.add("length");
            return this;
        }

        public Builder match(String match) {
            this.match = match;
            this.changedFields = changedFields.add("match");
            return this;
        }

        public Builder offset(Integer offset) {
            this.offset = offset;
            this.changedFields = changedFields.add("offset");
            return this;
        }

        public SensitiveContentEvidence build() {
            SensitiveContentEvidence _x = new SensitiveContentEvidence();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "microsoft.graph.sensitiveContentEvidence";
            _x.length = length;
            _x.match = match;
            _x.offset = offset;
            return _x;
        }
    }

    private SensitiveContentEvidence _copy() {
        SensitiveContentEvidence _x = new SensitiveContentEvidence();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.length = length;
        _x.match = match;
        _x.offset = offset;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("SensitiveContentEvidence[");
        b.append("length=");
        b.append(this.length);
        b.append(", ");
        b.append("match=");
        b.append(this.match);
        b.append(", ");
        b.append("offset=");
        b.append(this.offset);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}
